@@ -6,20 +6,27 @@ from .models import EntryCharacter, Rotation
 from .forms import NewEntryForm, NewShareFormSet, NewRoleFormSet
 
 
-def running_averages(user, start_date, end_date=timezone.now()):
+def running_averages(user, start_date, end_date=None):
+    if end_date is None:
+        end_date = timezone.now()
+
     rotations = Rotation.objects.filter(closed_at__range=(start_date, end_date)).get_setup_summary().filter(user=user).values('total_setups')
-    result = EntryCharacter.objects.filter(entry__rotation__closed_at__range=(start_date, end_date), user=user)\
-        .values('user').order_by()\
-        .annotate(helped_setups=Coalesce(Subquery(rotations[:1]), 0))\
-        .annotate(estimated_total=Sum('estimated_share_total'))\
-        .annotate(actual_total=Sum('actual_share_total'))\
+    result = (
+        EntryCharacter.objects
+        .filter(entry__rotation__closed_at__range=(start_date, end_date), user=user)
+        .with_totals()
+        .values('user').order_by()
+        .annotate(helped_setups=Coalesce(Subquery(rotations[:1]), 0))
+        .annotate(estimated_total=Sum('estimated_share_total'))
+        .annotate(actual_total=Sum('actual_share_total'))
         .values(
-        'helped_setups',
-        'estimated_total',
-        'actual_total'
+            'helped_setups',
+            'estimated_total',
+            'actual_total'
+        )
     )
 
-    if result.exists():
+    if result:
         return result[0]
     else:
         return {}
