@@ -12,7 +12,7 @@ logger = get_extension_logger(__name__)
 
 
 class NewEntryForm(forms.Form):
-    estimated_total = forms.FloatField(min_value=1, max_value=1000000000000, initial=0, required=True, widget=forms.NumberInput(attrs={'style': 'width: 50%'}))
+    estimated_total = forms.IntegerField(min_value=1, max_value=1000000000000, initial=0, required=True, widget=forms.TextInput(attrs={'style': 'width: 50%', 'class': 'localized-input', 'minvalue': 1, 'maxvalue': 1000000000000}))
 
 
 class NewRoleForm(forms.Form):
@@ -54,7 +54,7 @@ class NewShareForm(forms.Form):
     user = UserPkField(required=True, widget=forms.TextInput(attrs={'style': 'display: none;', 'class': 'user-pk-list'}))
     character = CharacterPkField(required=True, widget=forms.TextInput(attrs={'style': 'display: none;', 'class': 'character-pk-list'}))
     helped_setup = forms.BooleanField(required=False, widget=forms.CheckboxInput(attrs={'class': 'setup'}))
-    site_count = forms.IntegerField(min_value=1, required=True, widget=forms.NumberInput(attrs={'style': 'width: 10ch;'}))
+    site_count = forms.IntegerField(min_value=0, required=True, widget=forms.NumberInput(attrs={'style': 'width: 10ch;'}))
     role = forms.ChoiceField(required=True, widget=forms.Select(attrs={'class': 'form-control', 'style': 'height: auto;'}))
 
 
@@ -92,4 +92,4 @@ class NewRotationForm(forms.ModelForm):
 
 
 class CloseRotationForm(forms.Form):
-    sales_value = forms.FloatField(min_value=1, required=True)
+    sales_value = forms.IntegerField(min_value=1, required=True, widget=forms.TextInput(attrs={'class': 'localized-input'}))
