@@ -27,6 +27,8 @@ logger = get_extension_logger(__name__)
 RUNNING_AVERAGES_CACHE_PREFIX = 'pve_running_averages'
 RUNNING_AVERAGES_CACHE_TIMEOUT = 60 * 60
 
+ROTATION_SUMMARY_CACHE_TIMEOUT = 60 * 60 * 24
+
 
 @login_required
 @permission_required('allianceauth_pve.access_pve')
@@ -37,8 +39,19 @@ def index(request):
 @login_required
 @permission_required('allianceauth_pve.access_pve')
 def dashboard(request):
-    open_rots = Rotation.objects.filter(is_closed=False).order_by('-priority')
-    closed_rots = Rotation.objects.filter(is_closed=True).order_by('-closed_at')
+    open_rots = (
+        Rotation.objects
+        .annotate(summary_count=Count('entries__ratting_shares__user', distinct=True))
+        .filter(is_closed=False)
+        .order_by('-priority')
+    )
+
+    closed_rots = (
+        Rotation.objects
+        .annotate(summary_count=Count('entries__ratting_shares__user', distinct=True))
+        .filter(is_closed=True)
+        .order_by('-closed_at')
+    )
 
     paginator_open = Paginator(open_rots, 10)
     paginator_closed = Paginator(closed_rots, 10)
@@ -88,17 +101,20 @@ def dashboard(request):
 def rotation_view(request, rotation_id):
     r = get_object_or_404(Rotation, pk=rotation_id)
 
+    summary_cache_key = f"ratting_summary_{rotation_id}"
+
     if request.method == 'POST' and not r.is_closed and request.user.has_perm('allianceauth_pve.manage_rotations'):
         copied_data = request.POST.copy()
         copied_data['sales_value'] = copied_data['sales_value'].replace(',', '')
         closeform = CloseRotationForm(copied_data)
 
         if closeform.is_valid():
-            with transaction.atomic():
-                r.actual_total = closeform.cleaned_data['sales_value']
-                r.is_closed = True
-                r.closed_at = timezone.now()
-                r.save()
+            r.actual_total = closeform.cleaned_data['sales_value']
+            r.is_closed = True
+            r.closed_at = timezone.now()
+            r.save()
+
+            cache.delete(summary_cache_key)
 
             closeform = None
     elif not r.is_closed:
@@ -106,16 +122,27 @@ def rotation_view(request, rotation_id):
     else:
         closeform = None
 
-    summary = r.summary.order_by('-estimated_total').values(
-        'user',
-        'helped_setups',
-        'estimated_total',
-        'actual_total',
-        character_name=F('user__profile__main_character__character_name'),
-        character_id=F('user__profile__main_character__character_id'),
-    )
+    summary = cache.get(summary_cache_key)
+    if summary is None:
+        summary = r.summary.order_by('-estimated_total').values(
+            'user',
+            'helped_setups',
+            'estimated_total',
+            'actual_total',
+            character_name=F('user__profile__main_character__character_name'),
+            character_id=F('user__profile__main_character__character_id'),
+        )
 
-    summary_count_half = summary.count() // 2
+        cache.set(summary_cache_key, summary, ROTATION_SUMMARY_CACHE_TIMEOUT)
+
+    summary_count_half = (
+        r
+        .entries
+        .aggregate(
+            res=Count('ratting_shares__user', distinct=True)
+        )['res']
+        // 2
+    )
 
     entries_paginator = Paginator(r.entries.order_by('-created_at'), 10)
     page = request.GET.get('page')
@@ -245,6 +272,8 @@ def add_entry(request, rotation_id, entry_id=None):
 
             messages.success(request, 'Entry added successfully')
 
+            cache.delete(f"ratting_summary_{rotation_id}")
+
             return redirect('allianceauth_pve:rotation_view', rotation_id)
 
         else:
@@ -305,6 +334,8 @@ def delete_entry(request, entry_id):
     entry.delete()
     messages.success(request, "Entry deleted successfully")
 
+    cache.delete(f"ratting_summary_{rotation_id}")
+
     return redirect('allianceauth_pve:rotation_view', rotation_id)
 
 
